@@ -95,7 +95,8 @@ class GrobidConverter(ConverterBase):
                                         f.write(chunk)
                                 f.seek(0)
                                 doc = file_to_doc(
-                                    UploadFile(url.path, f, "application/pdf"), params, client
+                                    UploadFile(url.path, f, "application/pdf"), params, client,
+                                    original=input
                                 )
                                 docs.append(doc)
 
@@ -124,7 +125,7 @@ class GrobidConverter(ConverterBase):
         return GrobidParameters
 
 
-def file_to_doc(source: UploadFile, params, client):
+def file_to_doc(source: UploadFile, params, client, original=None):
     doc = None
     form = ProcessForm(
         segment_sentences="1" if params.sentences else "0",
@@ -137,7 +138,7 @@ def file_to_doc(source: UploadFile, params, client):
     r = process_fulltext_document.sync_detailed(client=client, multipart_data=form)
     if r.is_success:
         doc = article_to_doc(r, params)
-        doc.metadata['original'] = source.filename
+        doc.metadata['original'] = original or source.filename
     else:
         r.raise_for_status()
     return doc
